@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1402';
+our $VERSION = '0.1403';
 
 use Moo;
 use Music::Chord::Note;
@@ -289,7 +289,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1402
+version 0.1403
 
 =head1 SYNOPSIS
 
@@ -511,13 +511,13 @@ set its value to C<0> zero.
 The B<leading> chord is a number (1-7) for the scale chord to use for
 the first C<half> cadence chord.  For the key of C<C major> this is:
 
-  CM: 1
-  Dm: 2
-  Em: 3
-  FM: 4
-  GM: 5
-  Am: 6
-  Bo: 7
+  1: C maj
+  2: D min
+  3: E min
+  4: F maj
+  5: G maj
+  6: A min
+  7: B dim
 
 If an B<inversion> is defined for the C<half> cadence, the chords are
 inverted as described above for the C<imperfect> cadence.
@@ -528,36 +528,35 @@ the third inversion and the second by the first inversion.
 
 Here is a summary showing resolutions and options:
 
- 1. deceptive -> V-vi or V-IV
+ 1. Deceptive -> V-vi or V-IV
     variation
         1: final chord = vi
         2: final chord = IV
 
- 2. evaded -> inverted V-I 7th chords
+ 2. Evaded -> inverted V-I 7th chords
     inversion
         1: 1st, 2nd, or 3rd applied to first chord
         2: "                           second chord
 
- 3. half -> <leading>-IV and possibly inverted
+ 3. Half -> <leading>-V and possibly inverted
     leading: first chord = 1-7
     inversion
         as above (3rd inversion only for 7th chords)
 
- 4. imperfect -> V-I or vii-I or V-I inverted
+ 4. Imperfect -> V-I or vii-I or V-I inverted
     variation (no inversion)
         1: first chord = V
         2: first chord = vii
     inversion (variation ignored)
         as above (3rd inversion only for 7th chords)
 
- 5. perfect -> V-I + tonic of I added an octave above
+ 5. Perfect -> V-I + tonic added an octave above
 
- 6. plagal -> IV-I
+ 6. Plagal -> IV-I
 
 =head1 SEE ALSO
 
-The F<eg/cadence>, F<eg/synopsis>, F<t/01-methods.t> and
-F<t/02-methods.t> files in this distribution.
+The F<eg/*> and F<t/*> programs in this distribution
 
 L<Moo>
 
